set define off verify off feedback off
whenever sqlerror exit sql.sqlcode rollback
--------------------------------------------------------------------------------
--
-- ORACLE Application Express (APEX) export file
--
-- You should run the script connected to SQL*Plus as the Oracle user
-- APEX_050000 or as the owner (parsing schema) of the application.
--
-- NOTE: Calls to apex_application_install override the defaults below.
--
--------------------------------------------------------------------------------
begin
wwv_flow_api.import_begin (
 p_version_yyyy_mm_dd=>'2013.01.01'
,p_release=>'5.0.0.00.32'
,p_default_workspace_id=>21902424501456003
,p_default_application_id=>1807
,p_default_owner=>'JOHN'
);
end;
/
prompt --application/ui_types
begin
null;
end;
/
prompt --application/shared_components/plugins/item_type/com_oracle_apex_icon_select_list
begin
wwv_flow_api.create_plugin(
 p_id=>wwv_flow_api.id(2704185839264876337)
,p_plugin_type=>'ITEM TYPE'
,p_name=>'COM.ORACLE.APEX.ICON_SELECT_LIST'
,p_display_name=>'Icon Select List'
,p_supported_ui_types=>'DESKTOP:JQM_SMARTPHONE'
,p_javascript_file_urls=>wwv_flow_utilities.join(wwv_flow_t_varchar2(
'#IMAGE_PREFIX#libraries/apex/#MIN_DIRECTORY#widget.iconList#MIN#.js',
'#PLUGIN_FILES#iconSelectList#MIN#.js'))
,p_css_file_urls=>'#PLUGIN_FILES#iconSelectList#MIN#.css'
,p_plsql_code=>wwv_flow_utilities.join(wwv_flow_t_varchar2(
'/*',
' * Common procedure used when the list is first rendered any when it is refreshed',
' * with Ajax. This renders all the list items including an initial null value',
' * and any extra values as needed.',
' */',
'procedure print_items(',
'    p_item                in apex_plugin.t_page_item,',
'    p_column_value_list   in apex_plugin_util.t_column_value_list,',
'    p_value_list          in out apex_application_global.vc_arr2,',
'    p_value               in out varchar2,',
'    p_has_tooltips        out boolean,',
'    p_has_details         out boolean)',
'is',
'    -- columns of the LOV query results. All but the first two are optional',
'    c_label     constant pls_integer := 1;',
'    c_return    constant pls_integer := 2;',
'    c_detail    constant pls_integer := 3;',
'    c_icon      constant pls_integer := 4;',
'    c_tooltip   constant pls_integer := 5;',
'    c_css_class constant pls_integer := 6;',
'    c_url       constant pls_integer := 7;',
'',
'    l_multiple          boolean       := nvl(p_item.attribute_03, ''N'')=''Y'';',
'    l_icon_type         varchar2(200) := nvl(p_item.attribute_05, ''fa'');',
'    l_escape            boolean       := p_item.escape_output;',
'',
'    l_idx               pls_integer;',
'',
'    procedure print_item(',
'        p_return      in varchar2,',
'        p_label       in varchar2,',
'        p_detail      in varchar2 default null,',
'        p_icon        in varchar2 default null,',
'        p_tooltip     in varchar2 default null,',
'        p_css_class   in varchar2 default null,',
'        p_url         in varchar2 default null,',
'        p_is_selected in boolean default false)',
'    is',
'        l_is_selected   boolean := false;',
'    begin',
'        if p_is_selected then',
'            -- if caller says it is selected then it is',
'            l_is_selected := true;',
'        else',
'            -- select this item if it is one of the current values of the item',
'            if l_multiple then',
'                l_idx := apex_plugin_util.get_position_in_list(p_value_list, p_return);',
'                if l_idx is not null then',
'                    l_is_selected := true;',
'                    -- remove as we go and what remains in the end is handled as an extra',
'                    p_value_list.delete (l_idx);',
'                else',
'                    l_is_selected := false;',
'                end if;',
'            else',
'                -- for a single value select list do a simple compare, but only',
'                -- if we haven''t already selected a value',
'                if not l_is_selected and apex_plugin_util.is_equal(p_return, p_value) then',
'                    l_is_selected := true;',
'                    p_value_list.delete (1);',
'                else',
'                    l_is_selected := false;',
'                end if;',
'            end if;',
'        end if;',
'',
'        p_has_details := false;',
'        p_has_tooltips := false;',
'',
'        sys.htp.prn(''<li data-value="'' || apex_escape.html(p_return) || ''"'' ||',
'                    case when p_url is not null then '' data-url="'' || p_url || ''"'' end || '' class="'' ||',
'                    case when p_css_class is not null then p_css_class end ||',
'                    case when l_is_selected then '' is-selected'' end || ''">'');',
'        if p_icon is not null then',
'            sys.htp.prn(''<span class="a-IconList-icon '' || l_icon_type || '' '' || p_icon || ''"></span>'' );',
'        end if;',
'        sys.htp.prn(''<span class="a-IconList-label">'' || apex_plugin_util.escape(p_label, l_escape) || ''</span>'' );',
'        if p_detail is not null then',
'            p_has_details := true;',
'            sys.htp.prn(''<span class="a-IconList-detail">'' || apex_plugin_util.escape(p_detail, l_escape) || ''</span>'' );',
'        end if;',
'        if p_tooltip is not null then',
'            p_has_tooltips := true;',
'            sys.htp.prn(''<span class="a-IconList-tooltip" style="display:none">'' || apex_plugin_util.escape(p_tooltip, l_escape) || ''</span>'' );',
'        end if;',
'        sys.htp.prn(''</li>'');',
'',
'    end print_item;',
'',
'begin',
'',
'    -- render display null entry',
'    if p_item.lov_display_null then',
'        -- for a single select list we default to the null value if the value doesn''t contain a value',
'        if not l_multiple then',
'            p_value := nvl(p_value, p_item.lov_null_value);',
'        end if;',
'',
'        print_item(',
'            p_return  => p_item.lov_null_value,',
'            p_label => p_item.lov_null_text);',
'',
'    end if;',
'',
'    -- render all the items',
'    for i in 1 .. p_column_value_list(c_label).count',
'    loop',
'        -- print the item.',
'        -- Note: this call will also remove the value from p_value_list if it has been found!',
'        print_item(',
'            p_return     => replace(replace(p_column_value_list(c_return)(i), ''&SESSION.'', ''&SESSION''), ''&SESSION'', apex_application.g_instance),',
'            p_label      => p_column_value_list(c_label)(i),',
'            p_detail     => case when p_column_value_list.exists(c_detail) then p_column_value_list(c_detail)(i) else null end,',
'            p_icon       => case when p_column_value_list.exists(c_icon) then p_column_value_list(c_icon)(i) else null end,',
'            p_tooltip    => case when p_column_value_list.exists(c_tooltip) then p_column_value_list(c_tooltip)(i) else null end,',
'            p_css_class  => case when p_column_value_list.exists(c_css_class) then p_column_value_list(c_css_class)(i) else null end,',
'            p_url        => case when p_column_value_list.exists(c_url) then p_column_value_list(c_url)(i) else null end);',
'    end loop;',
'',
'    -- render extras if any',
'    -- If there are still values (they haven''t been found in the database) show at least the value if extra values should be displayed',
'    if p_value_list.count > 0 and p_item.lov_display_extra then',
'        l_idx := p_value_list.first;',
'        while l_idx is not null',
'        loop',
'            if p_value_list(l_idx) is not null then',
'                print_item(',
'                    p_label         => p_value_list(l_idx),',
'                    p_return        => p_value_list(l_idx),',
'                    p_is_selected   => true);',
'            end if;',
'            l_idx := p_value_list.next(l_idx);',
'        end loop;',
'    end if;',
'',
'end print_items;',
'',
'/*',
' * This function is responsible for rendering the HTML of the Icon Select List page item.',
' * It is also responsible for setting up any necessary JavaScritpt to run when the page loads.',
' * The render function has a well defined interface which every plug-in has to implement. ',
' * It''s designed in a way that future enhancements to the interface will not',
' * break existing plug-ins.',
' */',
'function render_icon_select_list(',
'    p_item                in apex_plugin.t_page_item,',
'    p_plugin              in apex_plugin.t_plugin,',
'    p_value               in varchar2,',
'    p_is_readonly         in boolean,',
'    p_is_printer_friendly in boolean)',
'    return apex_plugin.t_page_item_render_result',
'is',
'    l_url               varchar2(4000);',
'    l_onload_code       varchar2(32767);',
'    l_value             varchar2(32767) := case when p_value = p_item.lov_null_value then null else p_value end;',
'    l_value_list        apex_application_global.vc_arr2;',
'',
'    -- Dynamic attribute mapping',
'    l_sel_action        varchar2(30)   := nvl(p_item.attribute_01, ''NONE'');',
'    l_act_action        varchar2(30)   := nvl(p_item.attribute_02, ''NONE'');',
'    l_multiple          boolean        := nvl(p_item.attribute_03, ''N'')=''Y'';',
'    l_item_size         varchar2(30)   := nvl(p_item.attribute_04, ''t-medium'');',
'                        -- attribute_05 (icon type) is only needed by print_items',
'    l_height            varchar2(30)   := p_item.attribute_06;',
'    l_context_menu      varchar2(8000) := p_item.attribute_07;',
'',
'    l_name              varchar2(30);',
'    l_column_value_list apex_plugin_util.t_column_value_list;',
'    l_has_tooltips      boolean; -- this gets set based on the list data',
'    l_has_details       boolean; -- this gets set based on the list data',
'',
'    l_result            apex_plugin.t_page_item_render_result;',
'',
'begin',
'    -- if it''s a multi select list we have to split the current value',
'    if l_sel_action = ''NONE'' and l_multiple then',
'        l_value_list := apex_util.string_to_table(p_value, '':'');',
'    else',
'        if l_value is not null then',
'            l_value_list(1) := l_value;',
'        end if;',
'        -- just in case',
'        l_multiple := false;',
'    end if;',
'',
'    -- p_is_readonly and p_is_printer_friendly are not supported - the iconList is rendered the same way',
'',
'    l_name := apex_plugin.get_input_name_for_page_item(l_multiple);',
'',
'    -- get all values',
'    l_column_value_list := apex_plugin_util.get_data (',
'                               p_sql_statement      => p_item.lov_definition,',
'                               p_min_columns        => 2,',
'                               p_max_columns        => 7,',
'                               p_component_name     => p_item.name,',
'                               p_search_type        => null,',
'                               p_search_column_no   => null,',
'                               p_search_string      => null );',
'',
'    -- render hidden item to hold selection',
'    sys.htp.prn(''<input type="hidden" value="'' || p_value || ''" id="'' || p_item.name || ''_VALUE" name="'' || l_name || ''">'');',
'    -- render icon list markup',
'    sys.htp.prn(',
'        ''<div class="a-IconSelectList-wrapper '' || p_item.element_css_classes || ''" '' ||',
'        case when l_height is not null then ''style="height:'' || l_height || ''px" '' end || ',
'        p_item.element_attributes || ''><ul id="'' ||',
'        p_item.name || ''" class="a-IconList--pageItem '' || l_item_size || ''" '' ||',
'        case when p_item.label_id is not null then '' aria-labelledby="'' || p_item.label_id || ''" '' end ||',
'        ''>'' );',
'',
'    print_items(',
'        p_item => p_item,',
'        p_column_value_list => l_column_value_list,',
'        p_value_list => l_value_list, ',
'        p_value => l_value,',
'        p_has_tooltips => l_has_tooltips, -- output',
'        p_has_details => l_has_details);  -- output',
'',
'    -- end the list markup',
'    sys.htp.prn(''</ul></div>'');',
'',
'    l_onload_code := ''com_oracle_apex_icon_select_list('' ||',
'                          apex_javascript.add_value(p_item.name) ||',
'                          ''{'' ||',
'                          case when p_item.lov_display_null then',
'                              apex_javascript.add_attribute(''nullValue'', p_item.lov_null_value, false)',
'                          end ||',
'                          apex_javascript.add_attribute(''hasTooltips'', l_has_tooltips) ||',
'                          apex_javascript.add_attribute(''hasDetails'', l_has_details) ||',
'                          case when l_context_menu is not null then ''contextMenu: '' || l_context_menu || '',''  end ||',
'                          apex_javascript.add_attribute(''selectionAction'', l_sel_action) ||',
'                          apex_javascript.add_attribute(''activationAction'', l_act_action) ||',
'                          apex_javascript.add_attribute(''optionAttributes'', p_item.element_option_attributes) ||',
'                          apex_javascript.add_attribute(''ajaxIdentifier'', apex_plugin.get_ajax_identifier);',
'',
'    -- if a cascading LOV add the necesary options',
'    if p_item.lov_cascade_parent_items is not null then',
'        l_onload_code := l_onload_code || apex_javascript.add_attribute(''dependingOnSelector'',',
'                                                                        apex_plugin_util.page_item_names_to_jquery(p_item.lov_cascade_parent_items)) ||',
'                          apex_javascript.add_attribute(''optimizeRefresh'', p_item.ajax_optimize_refresh) ||',
'                          apex_javascript.add_attribute(''pageItemsToSubmit'', apex_plugin_util.page_item_names_to_jquery(p_item.ajax_items_to_submit));',
'    end if;',
'',
'    l_onload_code := l_onload_code || apex_javascript.add_attribute(''multiple'', l_multiple, false) || ''});'';',
'',
'    apex_javascript.add_onload_code(p_code => l_onload_code);',
'    l_result.is_navigable := true;',
'',
'    return l_result;',
'end render_icon_select_list;',
'',
'/*',
' * This function is responsible for handling all ajax requests for the Icon Select',
' * List plugin. This plugin supports only one action to take when an ajax request',
' * is received and that is to refresh the list contents. The list items are',
' * rendered just like the initial rendering except on a refresh there is no selection.',
' * The ajax function has a well defined interface which every plug-in has to implement. ',
' * It''s designed in a way that future enhancements to the interface will not',
' * break existing plug-ins.',
' */',
'function ajax_icon_select_list(',
'    p_item   in apex_plugin.t_page_item,',
'    p_plugin in apex_plugin.t_plugin)',
'    return apex_plugin.t_page_item_ajax_result',
'is',
'    l_column_value_list  apex_plugin_util.t_column_value_list;',
'    l_dont_care          boolean       := false;',
'    l_value              varchar2(32767); -- not used because there is no selection',
'    l_value_list         apex_application_global.vc_arr2;  -- not used because there is no selection',
'    l_escape             boolean       := p_item.escape_output;',
'    l_result             apex_plugin.t_page_item_ajax_result;',
'begin',
'    -- get all values',
'    l_column_value_list := apex_plugin_util.get_data(',
'                               p_sql_statement      => p_item.lov_definition,',
'                               p_min_columns        => 2,',
'                               p_max_columns        => 7,',
'                               p_component_name     => p_item.name,',
'                               p_search_type        => null,',
'                               p_search_column_no   => null,',
'                               p_search_string      => null);',
'',
'    -- render them',
'    print_items(',
'        p_item => p_item,',
'        p_column_value_list => l_column_value_list,',
'        p_value_list => l_value_list,',
'        p_value => l_value,',
'        p_has_tooltips => l_dont_care,',
'        p_has_details => l_dont_care);',
'',
'    return l_result;',
'end ajax_icon_select_list;',
''))
,p_render_function=>'render_icon_select_list'
,p_ajax_function=>'ajax_icon_select_list'
,p_standard_attributes=>'VISIBLE:SESSION_STATE:ESCAPE_OUTPUT:SOURCE:ELEMENT:ENCRYPT:LOV:LOV_REQUIRED:LOV_DISPLAY_NULL:CASCADING_LOV'
,p_sql_min_column_count=>2
,p_sql_max_column_count=>7
,p_sql_examples=>wwv_flow_utilities.join(wwv_flow_t_varchar2(
'<dl>',
'<dt>List of values based on SQL query. No extras.</dt>',
'<dd><pre>',
'select ename as d,',
'       empno as r',
'  from emp',
' order by 1',
'</pre></dd>',
'<dt>List of values with detail, icon, tooltip, and css class.</dt>',
'<dd><pre>',
'select ename d,',
'       empno r,',
'       hiredate detail,',
'       ''fa-user'' icon,',
'       job tooltip,',
'       case when comm is not null then ''state-comm'' else ''state-sal'' end css_class',
'  from emp ',
' order by 1',
'</pre>',
'<p>The css_class column allows you to specify a css class for each item and then add css rules to ',
'your page to style these specific items. There is a seventh column that is rendered as the data-url ',
'attribute. This allows the return value to be a key while still providing an APEX url for use by JavaScript.</p>',
'</dd>',
'<dt>List of values with bind variable</dt>',
'<dd><pre>',
'select ename,',
'       empno,',
'       null as detail,',
'       ''fa-user'' as icon',
'  from emp',
' where deptno = :P3_DEPTNO ',
' order by 1',
'</pre>',
'<p>Note: Set <em>Cascading LOV Parent Item(s)</em> attribute to <code>P3_DEPTNO</code> if <code>P3_DEPTNO</code> is a modifiable page item on the same page.</dd>',
'</dl>'))
,p_substitute_attributes=>true
,p_subscribe_plugin_settings=>true
,p_help_text=>wwv_flow_utilities.join(wwv_flow_t_varchar2(
'<p>A visually rich replacement for a Select List (with height greater than 1). Icon Select List is a 2D grid of choices from which the user can select one or more items.',
'It supports an icon, label text, extra details text, tooltip, and CSS class for each item of the list.</p>',
'<p>If any of the text fields will contain markup you must set security attribute Escape special characters to No and in the SQL Query make sure you escape any untrusted data.</p>'))
,p_version_identifier=>'1.0'
,p_about_url=>'http://apex.oracle.com/plugins'
,p_files_version=>32
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(2704187676737987456)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>1
,p_display_sequence=>10
,p_prompt=>'Page Action on Selection'
,p_attribute_type=>'SELECT LIST'
,p_is_required=>true
,p_default_value=>'NONE'
,p_is_translatable=>false
,p_lov_type=>'STATIC'
,p_help_text=>'<p>Select the action to take when a list item is selected. Note: doing any page navigation or submit when the selection changes may present a usability or accessibility issue. Consider using Page Action on Activation instead.<p>'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704195126142104947)
,p_plugin_attribute_id=>wwv_flow_api.id(2704187676737987456)
,p_display_sequence=>10
,p_display_value=>'None'
,p_return_value=>'NONE'
,p_help_text=>'Do nothing on selection (recommended).'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704195798168109992)
,p_plugin_attribute_id=>wwv_flow_api.id(2704187676737987456)
,p_display_sequence=>20
,p_display_value=>'Submit Page'
,p_return_value=>'SUBMIT'
,p_help_text=>'Submit the page with the page REQUEST set to the page item name.'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704196357052116762)
,p_plugin_attribute_id=>wwv_flow_api.id(2704187676737987456)
,p_display_sequence=>30
,p_display_value=>'Redirect to URL'
,p_return_value=>'REDIRECT_URL'
,p_help_text=>'Redirect to the URL given by the item value. The item return values in the list must be valid URLs.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(2704189983045026801)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>2
,p_display_sequence=>20
,p_prompt=>'Page Action on Activation'
,p_attribute_type=>'SELECT LIST'
,p_is_required=>true
,p_default_value=>'NONE'
,p_is_translatable=>false
,p_lov_type=>'STATIC'
,p_help_text=>'<p>Select the action to take when a list item is activated. An item is activated by pressing return when the item has focus or by double clicking on an item.<p>'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704197602577150618)
,p_plugin_attribute_id=>wwv_flow_api.id(2704189983045026801)
,p_display_sequence=>10
,p_display_value=>'None'
,p_return_value=>'NONE'
,p_help_text=>'Do nothing on activation.'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704198032619153992)
,p_plugin_attribute_id=>wwv_flow_api.id(2704189983045026801)
,p_display_sequence=>20
,p_display_value=>'Submit Page'
,p_return_value=>'SUBMIT'
,p_help_text=>'Submit the page with the page REQUEST set to the page item name.'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704198424292157178)
,p_plugin_attribute_id=>wwv_flow_api.id(2704189983045026801)
,p_display_sequence=>30
,p_display_value=>'Redirect to URL'
,p_return_value=>'REDIRECT_URL'
,p_help_text=>'Redirect to the URL given by the item value. The item return values in the list must be valid URLs.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(2704192991562045347)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>3
,p_display_sequence=>30
,p_prompt=>'Multiple Selection'
,p_attribute_type=>'CHECKBOX'
,p_is_required=>false
,p_default_value=>'N'
,p_is_translatable=>false
,p_depending_on_attribute_id=>wwv_flow_api.id(2704187676737987456)
,p_depending_on_condition_type=>'EQUALS'
,p_depending_on_expression=>'NONE'
,p_help_text=>'<p>When yes multiple items can be selected. Otherwise only a single selection is allowed. Multiple values are returned colon separated.<p>'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(2704193768353064779)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>4
,p_display_sequence=>40
,p_prompt=>'Item Size'
,p_attribute_type=>'SELECT LIST'
,p_is_required=>true
,p_default_value=>'t-medium'
,p_is_translatable=>false
,p_lov_type=>'STATIC'
,p_help_text=>'<p>Controls the size of the item including the icon. The sizes and other styles can be overridden with your own CSS rules by targeting the classes t-small, t-medium, and t-large.</p>'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704199125249167739)
,p_plugin_attribute_id=>wwv_flow_api.id(2704193768353064779)
,p_display_sequence=>10
,p_display_value=>'Small'
,p_return_value=>'t-small'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704199541914168679)
,p_plugin_attribute_id=>wwv_flow_api.id(2704193768353064779)
,p_display_sequence=>20
,p_display_value=>'Medium'
,p_return_value=>'t-medium'
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(2704199969608169417)
,p_plugin_attribute_id=>wwv_flow_api.id(2704193768353064779)
,p_display_sequence=>30
,p_display_value=>'Large'
,p_return_value=>'t-large'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(2704194447623097697)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>5
,p_display_sequence=>50
,p_prompt=>'Icon Type Class'
,p_attribute_type=>'TEXT'
,p_is_required=>false
,p_default_value=>'fa'
,p_max_length=>30
,p_is_translatable=>false
,p_help_text=>'<p>This is the CSS class name that specifies the type of icons to use. For example "fa" is the value used to select Font Awesome icons.</p>'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(2704216140379712520)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>6
,p_display_sequence=>60
,p_prompt=>'Height'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'260'
,p_display_length=>10
,p_max_length=>10
,p_unit=>'px'
,p_is_translatable=>false
,p_help_text=>'<p>The height of the icon list in pixels. You can also leave this blank and provide your own CSS rules for setting the height of class a-IconSelectList-wrapper.</p>'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(2710318365571276799)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>7
,p_display_sequence=>70
,p_prompt=>'Context Menu'
,p_attribute_type=>'JAVASCRIPT'
,p_is_required=>false
,p_is_common=>false
,p_show_in_wizard=>false
,p_is_translatable=>false
,p_help_text=>wwv_flow_utilities.join(wwv_flow_t_varchar2(
'Create a context menu using the menu.widget. This is a JavaScript object that is passed to the menu widget as its option parameter. ',
'This is an advanced feature that requires writing JavaScript code.'))
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2F2A0D0A202A2049636F6E2053656C656374204C69737420706C7567696E0D0A202A20436F707972696768742028632920323031352C204F7261636C6520616E642F6F722069747320616666696C69617465732E20416C6C207269676874732072657365';
wwv_flow_api.g_varchar2_table(2) := '727665642E0D0A202A0D0A202A2054686520706C75672D696E206973206475616C206C6963656E73656420756E64657220746865204D495420616E642047504C206C6963656E7365733A0D0A202A2020687474703A2F2F7777772E6F70656E736F757263';
wwv_flow_api.g_varchar2_table(3) := '652E6F72672F6C6963656E7365732F6D69742D6C6963656E73652E7068700D0A202A2020687474703A2F2F7777772E676E752E6F72672F6C6963656E7365732F67706C2E68746D6C0D0A202A2F0D0A2F2A2066756E6374696F6E616C2063737320746F20';
wwv_flow_api.g_varchar2_table(4) := '737570706F7274207769646765742E69636F6E4C697374202A2F0D0A2E612D49636F6E4C697374207B0D0A202020206C6973742D7374796C653A206E6F6E65206F757473696465206E6F6E653B0D0A202020206F766572666C6F773A2068696464656E3B';
wwv_flow_api.g_varchar2_table(5) := '0D0A202020206D617267696E3A20303B0D0A2020202070616464696E673A203470783B0D0A202020202A7A6F6F6D3A20313B0D0A7D0D0A2E612D49636F6E4C6973743A6265666F72652C202E612D49636F6E4C6973743A6166746572207B0D0A20202020';
wwv_flow_api.g_varchar2_table(6) := '636F6E74656E743A202220223B0D0A20202020646973706C61793A207461626C653B0D0A7D0D0A2E612D49636F6E4C6973743A6166746572207B0D0A20202020636C6561723A20626F74683B0D0A7D0D0A2E612D49636F6E4C6973742E752D52544C202E';
wwv_flow_api.g_varchar2_table(7) := '612D49636F6E4C6973742D6974656D207B0D0A20202020666C6F61743A2072696768743B0D0A7D0D0A0D0A2E612D49636F6E4C6973742D6974656D207B0D0A20202020646973706C61793A20626C6F636B3B0D0A20202020666C6F61743A206C6566743B';
wwv_flow_api.g_varchar2_table(8) := '0D0A20202020746578742D6465636F726174696F6E3A206E6F6E653B0D0A7D0D0A0D0A2E612D49636F6E4C6973742D6974656D202E612D49636F6E4C6973742D6C6162656C207B0D0A20202020646973706C61793A20626C6F636B3B0D0A202020206F76';
wwv_flow_api.g_varchar2_table(9) := '6572666C6F773A2068696464656E3B0D0A7D0D0A2F2A2066756E6374696F6E616C2063737320746F20737570706F7274207468652069636F6E2073656C656374206C697374202A2F0D0A2E612D49636F6E53656C6563744C6973742D7772617070657220';
wwv_flow_api.g_varchar2_table(10) := '7B0D0A202020206F766572666C6F772D783A2068696464656E3B0D0A202020206F766572666C6F772D793A206175746F3B0D0A202020206865696768743A2032303070783B202F2A206A75737420612064656661756C742076616C7565202A2F0D0A2020';
wwv_flow_api.g_varchar2_table(11) := '2020626F726465723A2031707820736F6C696420236439643964393B0D0A20202020626F726465722D7261646975733A203270783B0D0A20202020636F6C6F723A20233333333B0D0A202020202F2A2074686520666F6C6C6F77696E6720616C6C6F7720';
wwv_flow_api.g_varchar2_table(12) := '746865206974656D2068656C7020283F2920627574746F6E20746F20676F206E65787420746F207468652069636F6E206C697374202A2F0D0A20202020646973706C61793A20696E6C696E652D626C6F636B3B0D0A2020202077696474683A203932253B';
wwv_flow_api.g_varchar2_table(13) := '0D0A7D0D0A2E612D49636F6E4C6973742D6974656D202E612D49636F6E4C6973742D64657461696C207B0D0A20202020646973706C61793A20626C6F636B3B0D0A202020206F766572666C6F773A2068696464656E3B0D0A7D0D0A0D0A2F2A207374796C';
wwv_flow_api.g_varchar2_table(14) := '6520637373202A2F0D0A2E612D49636F6E4C6973742D6974656D207B0D0A2020202070616464696E673A20387078203470783B0D0A202020206D617267696E3A2030203470782034707820303B0D0A20202020636F6C6F723A20233646364636463B0D0A';
wwv_flow_api.g_varchar2_table(15) := '20202020626F726465722D7261646975733A203370783B0D0A7D0D0A2E612D49636F6E4C6973742D6974656D3A686F766572207B0D0A20202020636F6C6F723A20233434343434343B0D0A202020206261636B67726F756E642D636F6C6F723A20234641';
wwv_flow_api.g_varchar2_table(16) := '464146413B0D0A20202020626F782D736861646F773A20302030203020317078207267626128302C20302C20302C20302E30352920696E7365743B0D0A7D0D0A2E612D49636F6E4C6973742D6974656D3A616374697665207B0D0A20202020636F6C6F72';
wwv_flow_api.g_varchar2_table(17) := '3A20233434343434343B0D0A202020206261636B67726F756E642D636F6C6F723A20234534453445343B0D0A20202020626F782D736861646F773A20302030203020317078207267626128302C20302C20302C20302E30352920696E7365743B0D0A7D0D';
wwv_flow_api.g_varchar2_table(18) := '0A2E612D49636F6E4C6973742D6974656D3A666F637573207B0D0A202020206F75746C696E653A206E6F6E653B0D0A20202020626F782D736861646F773A20302030203020317078202333393962656120696E7365743B0D0A7D0D0A2E612D49636F6E4C';
wwv_flow_api.g_varchar2_table(19) := '6973742D6974656D2E69732D73656C6563746564207B0D0A202020206261636B67726F756E642D636F6C6F723A20234632463246323B0D0A20202020626F782D736861646F773A20302030203020317078202333393962656120696E7365743B0D0A7D0D';
wwv_flow_api.g_varchar2_table(20) := '0A2E612D49636F6E4C6973742D6974656D2E69732D73656C65637465642E69732D666F6375736564207B0D0A20202020636F6C6F723A20233434343434343B0D0A20202020626F782D736861646F773A2030203020302031707820233339396265612069';
wwv_flow_api.g_varchar2_table(21) := '6E7365742C2030203020302031707820233339396265612C20302030203270782032707820726762612835372C203135352C203233342C20302E35293B0D0A202020206F75746C696E653A206E6F6E653B0D0A7D0D0A0D0A2E612D49636F6E4C6973742D';
wwv_flow_api.g_varchar2_table(22) := '6974656D202E612D49636F6E4C6973742D69636F6E207B0D0A202020206D617267696E3A20387078206175746F3B0D0A20202020646973706C61793A20626C6F636B3B0D0A202020206C696E652D6865696768743A20313B0D0A20202020746578742D61';
wwv_flow_api.g_varchar2_table(23) := '6C69676E3A2063656E7465723B0D0A7D0D0A0D0A2E612D49636F6E4C6973742D6974656D202E612D49636F6E4C6973742D69636F6E3A6265666F7265207B0D0A20202020766572746963616C2D616C69676E3A20746F703B0D0A7D0D0A0D0A2E612D4963';
wwv_flow_api.g_varchar2_table(24) := '6F6E4C6973742D6C6162656C207B0D0A20202020746578742D6F766572666C6F773A20656C6C69707369733B0D0A20202020746578742D616C69676E3A2063656E7465723B0D0A2020202077686974652D73706163653A206E6F726D616C3B0D0A202020';
wwv_flow_api.g_varchar2_table(25) := '20666F6E742D73697A653A20313170783B0D0A202020206C696E652D6865696768743A20313470783B0D0A202020206865696768743A20323870783B0D0A202020206D617267696E2D746F703A203870783B0D0A7D0D0A0D0A2E612D49636F6E4C697374';
wwv_flow_api.g_varchar2_table(26) := '2D64657461696C207B0D0A20202020746578742D6F766572666C6F773A20656C6C69707369733B0D0A20202020746578742D616C69676E3A2063656E7465723B0D0A2020202077686974652D73706163653A206E6F777261703B0D0A20202020666F6E74';
wwv_flow_api.g_varchar2_table(27) := '2D73697A653A203970783B0D0A202020206C696E652D6865696768743A20313270783B0D0A202020206865696768743A20313270783B0D0A202020206D617267696E2D746F703A203470783B0D0A7D0D0A0D0A2E612D49636F6E4C6973742E742D686173';
wwv_flow_api.g_varchar2_table(28) := '44657461696C73202E612D49636F6E4C6973742D6C6162656C207B0D0A2020202077686974652D73706163653A206E6F777261703B0D0A202020206865696768743A20313470783B0D0A7D0D0A0D0A2E612D49636F6E4C6973742E742D68617344657461';
wwv_flow_api.g_varchar2_table(29) := '696C73202E612D49636F6E4C6973742D69636F6E207B0D0A202020206D617267696E2D746F703A20303B0D0A7D0D0A0D0A2F2A2064656661756C742073697A65202A2F0D0A2E612D49636F6E4C6973742E742D6D656469756D202E612D49636F6E4C6973';
wwv_flow_api.g_varchar2_table(30) := '742D69636F6E207B0D0A2020202077696474683A20333270783B0D0A202020206865696768743A20333270783B0D0A7D0D0A2E612D49636F6E4C6973742E742D6D656469756D202E612D49636F6E4C6973742D69636F6E3A6265666F7265207B0D0A2020';
wwv_flow_api.g_varchar2_table(31) := '2020666F6E742D73697A653A20333270783B0D0A7D0D0A2E612D49636F6E4C6973742E742D6D656469756D202E612D49636F6E4C6973742D6974656D207B0D0A2020202077696474683A2031323070783B0D0A202020206865696768743A20393070783B';
wwv_flow_api.g_varchar2_table(32) := '0D0A7D0D0A2F2A206C617267652073697A65202A2F0D0A2E612D49636F6E4C6973742E742D6C61726765202E612D49636F6E4C6973742D69636F6E207B0D0A2020202077696474683A20363470783B0D0A202020206865696768743A20363470783B0D0A';
wwv_flow_api.g_varchar2_table(33) := '7D0D0A2E612D49636F6E4C6973742E742D6C61726765202E612D49636F6E4C6973742D69636F6E3A6265666F7265207B0D0A20202020666F6E742D73697A653A20363470783B0D0A7D0D0A2E612D49636F6E4C6973742E742D6C61726765202E612D4963';
wwv_flow_api.g_varchar2_table(34) := '6F6E4C6973742D6974656D207B0D0A2020202077696474683A2031343070783B0D0A202020206865696768743A2031323070783B0D0A7D0D0A2F2A20736D616C6C2073697A65202A2F0D0A2E612D49636F6E4C6973742E742D736D616C202E612D49636F';
wwv_flow_api.g_varchar2_table(35) := '6E4C6973742D69636F6E207B0D0A2020202077696474683A20313670783B0D0A202020206865696768743A20313670783B0D0A7D0D0A2E612D49636F6E4C6973742E742D736D616C6C202E612D49636F6E4C6973742D69636F6E3A6265666F7265207B0D';
wwv_flow_api.g_varchar2_table(36) := '0A20202020666F6E742D73697A653A20313670783B0D0A7D0D0A2E612D49636F6E4C6973742E742D736D616C6C202E612D49636F6E4C6973742D6974656D207B0D0A2020202077696474683A2031303070783B0D0A202020206865696768743A20383070';
wwv_flow_api.g_varchar2_table(37) := '783B0D0A7D0D0A';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(2704186304177921659)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_file_name=>'iconSelectList.css'
,p_mime_type=>'text/css'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2F2A0D0A202A2049636F6E2053656C656374204C69737420706C7567696E0D0A202A20436F707972696768742028632920323031352C204F7261636C6520616E642F6F722069747320616666696C69617465732E20416C6C207269676874732072657365';
wwv_flow_api.g_varchar2_table(2) := '727665642E0D0A202A0D0A202A2054686520706C75672D696E206973206475616C206C6963656E73656420756E64657220746865204D495420616E642047504C206C6963656E7365733A0D0A202A2020687474703A2F2F7777772E6F70656E736F757263';
wwv_flow_api.g_varchar2_table(3) := '652E6F72672F6C6963656E7365732F6D69742D6C6963656E73652E7068700D0A202A2020687474703A2F2F7777772E676E752E6F72672F6C6963656E7365732F67706C2E68746D6C0D0A202A2F0D0A2F2A676C6F62616C20617065782A2F0D0A2866756E';
wwv_flow_api.g_varchar2_table(4) := '6374696F6E2820242C20756E646566696E65642029207B0D0A2275736520737472696374223B0D0A0D0A77696E646F772E636F6D5F6F7261636C655F617065785F69636F6E5F73656C6563745F6C697374203D2066756E6374696F6E28206974656D4964';
wwv_flow_api.g_varchar2_table(5) := '2C206F7074696F6E732029207B0D0A20202020766172206C697374496E70757424203D20242820222322202B206974656D4964202B20225F56414C5545222C20617065782E6750616765436F6E746578742420292C0D0A20202020202020206C69737424';
wwv_flow_api.g_varchar2_table(6) := '203D20242820222322202B206974656D49642C20617065782E6750616765436F6E746578742420293B0D0A0D0A202020202F2F20696E697469616C697A652069636F6E4C697374207769646765740D0A202020206C697374242E69636F6E4C6973742820';
wwv_flow_api.g_varchar2_table(7) := '7B0D0A20202020202020206E617669676174696F6E3A206F7074696F6E732E73656C656374696F6E416374696F6E20213D3D20224E4F4E45222C0D0A20202020202020206D756C7469706C653A206F7074696F6E732E6D756C7469706C652C0D0A202020';
wwv_flow_api.g_varchar2_table(8) := '20202020206C6162656C3A20222E612D49636F6E4C6973742D6C6162656C222C0D0A2020202020202020636F6E746578744D656E753A206F7074696F6E732E636F6E746578744D656E75203F206F7074696F6E732E636F6E746578744D656E75203A206E';
wwv_flow_api.g_varchar2_table(9) := '756C6C2C0D0A2020202020202020636F6E746578744D656E7549643A206F7074696F6E732E636F6E746578744D656E75203F206974656D4964202B20225F6D656E7522203A206E756C6C2C0D0A202020202020202061637469766174653A2066756E6374';
wwv_flow_api.g_varchar2_table(10) := '696F6E28206576656E742C2075692029207B0D0A2020202020202020202020207661722076616C7565733B0D0A20202020202020202020202069662028206F7074696F6E732E61637469766174696F6E416374696F6E203D3D3D20225355424D49542220';
wwv_flow_api.g_varchar2_table(11) := '7C7C206F7074696F6E732E73656C656374696F6E416374696F6E203D3D3D20225355424D4954222029207B0D0A2020202020202020202020202020202076616C756573203D2075692E76616C7565732E6A6F696E28223A22293B0D0A2020202020202020';
wwv_flow_api.g_varchar2_table(12) := '20202020202020206C697374496E707574242E76616C282076616C75657320293B0D0A20202020202020202020202020202020617065782E706167652E7375626D6974287B726571756573743A206974656D49647D293B0D0A2020202020202020202020';
wwv_flow_api.g_varchar2_table(13) := '207D20656C73652069662028206F7074696F6E732E61637469766174696F6E416374696F6E203D3D3D202252454449524543545F55524C22207C7C206F7074696F6E732E73656C656374696F6E416374696F6E203D3D3D202252454449524543545F5552';
wwv_flow_api.g_varchar2_table(14) := '4C222029207B0D0A20202020202020202020202020202020617065782E6E617669676174696F6E2E72656469726563742875692E76616C7565735B305D293B0D0A2020202020202020202020207D0D0A2020202020202020202020206576656E742E7072';
wwv_flow_api.g_varchar2_table(15) := '6576656E7444656661756C7428293B0D0A20202020202020207D2C0D0A202020202020202073656C656374696F6E4368616E67653A2066756E6374696F6E28206576656E742029207B0D0A2020202020202020202020207661722076616C756573203D20';
wwv_flow_api.g_varchar2_table(16) := '2428207468697320292E69636F6E4C69737428202267657453656C656374696F6E56616C7565732220293B0D0A20202020202020202020202076616C756573203D2076616C7565732E6A6F696E28223A22293B0D0A2020202020202020202020206C6973';
wwv_flow_api.g_varchar2_table(17) := '74496E707574242E76616C282076616C75657320292E747269676765722820226368616E67652220293B0D0A20202020202020207D0D0A202020207D20293B0D0A0D0A2020202069662028206F7074696F6E732E68617344657461696C732029207B0D0A';
wwv_flow_api.g_varchar2_table(18) := '20202020202020206C697374242E616464436C617373282022742D68617344657461696C732220293B0D0A202020207D0D0A0D0A202020202F2F206966207468652077696E646F7720726573697A65732074686572652069732061206368616E63652064';
wwv_flow_api.g_varchar2_table(19) := '756520746F20726573706F6E736976652064657369676E2074686174207468652069636F6E2073656C656374206C6973742070616765206974656D2073697A65206368616E6765730D0A2020202024282077696E646F7720292E6F6E2820226170657877';
wwv_flow_api.g_varchar2_table(20) := '696E646F77726573697A6564222C2066756E6374696F6E2829207B0D0A2020202020202020202020206C697374242E69636F6E4C697374282022726566726573682220293B0D0A20202020202020207D0D0A20202020293B0D0A0D0A2020202069662028';
wwv_flow_api.g_varchar2_table(21) := '206F7074696F6E732E686173546F6F6C746970732029207B0D0A20202020202020206C697374242E746F6F6C746970287B0D0A2020202020202020202020206974656D733A20226C69222C0D0A20202020202020202020202073686F773A20617065782E';
wwv_flow_api.g_varchar2_table(22) := '746F6F6C7469704D616E616765722E64656661756C7453686F774F7074696F6E28292C0D0A202020202020202020202020706F736974696F6E3A207B206D793A20226C6566742D323020746F702D3230222C2061743A2022726967687420626F74746F6D';
wwv_flow_api.g_varchar2_table(23) := '222C20636F6C6C6973696F6E3A2022666C697066697422207D2C0D0A202020202020202020202020636F6E74656E743A2066756E6374696F6E2829207B0D0A2020202020202020202020202020202072657475726E202428207468697320292E66696E64';
wwv_flow_api.g_varchar2_table(24) := '28222E612D49636F6E4C6973742D746F6F6C7469702220292E68746D6C28293B0D0A2020202020202020202020207D0D0A20202020202020207D293B0D0A202020207D0D0A0D0A202020202F2F20526567697374657220617065782E6974656D2063616C';
wwv_flow_api.g_varchar2_table(25) := '6C6261636B730D0A20202020617065782E7769646765742E696E6974506167654974656D28206974656D49642C207B0D0A202020202020202067657456616C75653A2066756E6374696F6E282029207B0D0A20202020202020202020202072657475726E';
wwv_flow_api.g_varchar2_table(26) := '206C697374496E707574242E76616C28293B0D0A20202020202020207D2C0D0A202020202020202073657456616C75653A2066756E6374696F6E282076616C75652029207B0D0A202020202020202020202020766172206974656D73203D205B5D3B0D0A';
wwv_flow_api.g_varchar2_table(27) := '2020202020202020202020206C697374496E707574242E76616C282076616C756520293B0D0A20202020202020202020202076616C7565203D20223A22202B2076616C7565202B20223A223B0D0A2020202020202020202020206C697374242E66696E64';
wwv_flow_api.g_varchar2_table(28) := '2820222E612D49636F6E4C6973742D6974656D2220292E656163682866756E6374696F6E2829207B0D0A20202020202020202020202020202020696620282076616C75652E696E6465784F662820223A22202B202428207468697320292E617474722822';
wwv_flow_api.g_varchar2_table(29) := '646174612D76616C75652229202B20223A222029203E3D20302029207B0D0A20202020202020202020202020202020202020206974656D732E707573682874686973293B0D0A202020202020202020202020202020207D0D0A2020202020202020202020';
wwv_flow_api.g_varchar2_table(30) := '207D293B0D0A2020202020202020202020206C697374242E69636F6E4C69737428202273657453656C656374696F6E222C2024286974656D732920293B0D0A20202020202020207D2C0D0A20202020202020206E756C6C56616C75653A202022222C0D0A';
wwv_flow_api.g_varchar2_table(31) := '2020202020202020656E61626C653A2066756E6374696F6E2829207B0D0A2020202020202020202020206C697374242E69636F6E4C6973742822656E61626C6522293B0D0A20202020202020207D2C0D0A202020202020202064697361626C653A206675';
wwv_flow_api.g_varchar2_table(32) := '6E6374696F6E2829207B0D0A2020202020202020202020206C697374242E69636F6E4C697374282264697361626C6522293B0D0A20202020202020207D2C0D0A2020202020202020736574466F637573546F3A2066756E6374696F6E2829207B0D0A2020';
wwv_flow_api.g_varchar2_table(33) := '202020202020202020202F2F20746869732073686F756C642072657475726E20746865206A5175657279206F626A65637420746F2073657420666F63757320746F20627574207468652069636F6E4C6973742077696467657420646F65736E277420776F';
wwv_flow_api.g_varchar2_table(34) := '726B2074686174207761790D0A2020202020202020202020202F2F20736F20646F2077686174206D75737420626520646F6E650D0A2020202020202020202020206C697374242E69636F6E4C697374282022666F6375732220293B0D0A20202020202020';
wwv_flow_api.g_varchar2_table(35) := '20202020202F2F20616E642072657475726E2066616B65206F626A656374207769746820666F637573206D6574686F6420746F206B6565702063616C6C65722068617070790D0A20202020202020202020202072657475726E207B666F6375733A66756E';
wwv_flow_api.g_varchar2_table(36) := '6374696F6E28297B7D7D3B0D0A20202020202020207D0D0A202020207D293B0D0A0D0A202020202F2F2069662073696E676C652073656C656374696F6E206D616B65207375726520736F6D657468696E672069732073656C65637465640D0A2020202069';
wwv_flow_api.g_varchar2_table(37) := '66202820216F7074696F6E732E6D756C7469706C65202626206C697374242E69636F6E4C69737428202267657453656C656374696F6E56616C7565732220292E6C656E677468203D3D3D20302029207B0D0A20202020202020206C697374242E69636F6E';
wwv_flow_api.g_varchar2_table(38) := '4C69737428202273657453656C656374696F6E222C206C697374242E6368696C6472656E28292E6669727374282920293B0D0A2020202020202020617065782E6974656D28206974656D496420292E73657456616C7565286C697374242E69636F6E4C69';
wwv_flow_api.g_varchar2_table(39) := '737428202267657453656C656374696F6E56616C756573222029293B0D0A202020207D0D0A0D0A202020202F2F20436C6561727320746865206578697374696E67206F7074696F6E730D0A2020202066756E6374696F6E20636C6561724C697374282920';
wwv_flow_api.g_varchar2_table(40) := '7B0D0A20202020202020206C697374242E656D70747928293B0D0A20202020202020206C697374496E707574242E76616C282222293B0D0A202020207D0D0A0D0A202020202F2F20436C6561727320746865206578697374696E67206974656D7320616E';
wwv_flow_api.g_varchar2_table(41) := '6420657865637574657320616E20616A61782063616C6C20746F20676574206E65772076616C7565732062617365640D0A202020202F2F206F6E2074686520646570656E64696E67206F6E206669656C64730D0A2020202066756E6374696F6E20726566';
wwv_flow_api.g_varchar2_table(42) := '726573682829207B0D0A2020202020202020617065782E7769646765742E7574696C2E636173636164696E674C6F76280D0A2020202020202020202020206C697374242C0D0A2020202020202020202020206F7074696F6E732E616A61784964656E7469';
wwv_flow_api.g_varchar2_table(43) := '666965722C0D0A2020202020202020202020207B2020706167654974656D733A202428206F7074696F6E732E706167654974656D73546F5375626D69742C20617065782E6750616765436F6E74657874242029207D2C0D0A202020202020202020202020';
wwv_flow_api.g_varchar2_table(44) := '7B0D0A202020202020202020202020202020206F7074696D697A65526566726573683A206F7074696F6E732E6F7074696D697A65526566726573682C0D0A20202020202020202020202020202020646570656E64696E674F6E3A202428206F7074696F6E';
wwv_flow_api.g_varchar2_table(45) := '732E646570656E64696E674F6E53656C6563746F722C20617065782E6750616765436F6E746578742420292C0D0A2020202020202020202020202020202064617461547970653A202268746D6C222C0D0A202020202020202020202020202020206C6F61';
wwv_flow_api.g_varchar2_table(46) := '64696E67496E64696361746F723A206C697374242E706172656E7428292C0D0A202020202020202020202020202020206C6F6164696E67496E64696361746F72506F736974696F6E3A20226166746572222C0D0A20202020202020202020202020202020';
wwv_flow_api.g_varchar2_table(47) := '737563636573733A2066756E6374696F6E286461746129207B0D0A20202020202020202020202020202020202020206C697374242E68746D6C28206461746120293B0D0A20202020202020202020202020202020202020206C697374242E69636F6E4C69';
wwv_flow_api.g_varchar2_table(48) := '7374282022726566726573682220293B0D0A20202020202020202020202020202020202020202F2F207265667265736820636C65617273207468652073656C656374696F6E206275742069662073696E676C652073656C656374206D616B652073757265';
wwv_flow_api.g_varchar2_table(49) := '20736F6D657468696E672069732073656C65637465640D0A202020202020202020202020202020202020202069662028216F7074696F6E732E6D756C7469706C6529207B0D0A2020202020202020202020202020202020202020202020206C697374242E';
wwv_flow_api.g_varchar2_table(50) := '69636F6E4C69737428202273657453656C656374696F6E222C206C697374242E6368696C6472656E28292E6669727374282920293B0D0A202020202020202020202020202020202020202020202020617065782E6974656D28206974656D496420292E73';
wwv_flow_api.g_varchar2_table(51) := '657456616C756528206C697374242E69636F6E4C69737428202267657453656C656374696F6E56616C75657322202920293B0D0A20202020202020202020202020202020202020207D0D0A202020202020202020202020202020207D2C0D0A2020202020';
wwv_flow_api.g_varchar2_table(52) := '2020202020202020202020636C6561723A20636C6561724C6973740D0A2020202020202020202020207D293B0D0A0D0A202020207D202F2F20726566726573680D0A0D0A202020202F2F2069662069742773206120636173636164696E67206C69737420';
wwv_flow_api.g_varchar2_table(53) := '7765206861766520746F20726567697374657220617065786265666F72657265667265736820616E64206368616E6765206576656E747320666F72206F7572206D6173746572730D0A2020202069662028206F7074696F6E732E646570656E64696E674F';
wwv_flow_api.g_varchar2_table(54) := '6E53656C6563746F722029207B0D0A20202020202020202428206F7074696F6E732E646570656E64696E674F6E53656C6563746F722C20617065782E6750616765436F6E746578742420290D0A2020202020202020202020202E6F6E2820226170657862';
wwv_flow_api.g_varchar2_table(55) := '65666F726572656672657368222C20636C6561724C69737420290D0A2020202020202020202020202E6368616E676528207265667265736820293B0D0A202020207D0D0A0D0A202020206C697374242E6F6E2820226170657872656672657368222C2072';
wwv_flow_api.g_varchar2_table(56) := '65667265736820293B0D0A7D3B0D0A0D0A7D292820617065782E6A517565727920293B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(2704186756590922649)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_file_name=>'iconSelectList.js'
,p_mime_type=>'application/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2E612D49636F6E4C6973747B6C6973742D7374796C653A6E6F6E65206F757473696465206E6F6E653B6F766572666C6F773A68696464656E3B6D617267696E3A303B70616464696E673A3470783B2A7A6F6F6D3A317D2E612D49636F6E4C6973743A6166';
wwv_flow_api.g_varchar2_table(2) := '7465722C2E612D49636F6E4C6973743A6265666F72657B636F6E74656E743A2220223B646973706C61793A7461626C657D2E612D49636F6E4C6973743A61667465727B636C6561723A626F74687D2E612D49636F6E4C6973742E752D52544C202E612D49';
wwv_flow_api.g_varchar2_table(3) := '636F6E4C6973742D6974656D7B666C6F61743A72696768747D2E612D49636F6E4C6973742D6974656D7B646973706C61793A626C6F636B3B666C6F61743A6C6566743B746578742D6465636F726174696F6E3A6E6F6E657D2E612D49636F6E4C6973742D';
wwv_flow_api.g_varchar2_table(4) := '6974656D202E612D49636F6E4C6973742D6C6162656C7B646973706C61793A626C6F636B3B6F766572666C6F773A68696464656E7D2E612D49636F6E53656C6563744C6973742D777261707065727B6F766572666C6F772D783A68696464656E3B6F7665';
wwv_flow_api.g_varchar2_table(5) := '72666C6F772D793A6175746F3B6865696768743A32303070783B626F726465723A31707820736F6C696420236439643964393B626F726465722D7261646975733A3270783B636F6C6F723A233333333B646973706C61793A696E6C696E652D626C6F636B';
wwv_flow_api.g_varchar2_table(6) := '3B77696474683A3932257D2E612D49636F6E4C6973742D6974656D202E612D49636F6E4C6973742D64657461696C7B646973706C61793A626C6F636B3B6F766572666C6F773A68696464656E7D2E612D49636F6E4C6973742D6974656D7B70616464696E';
wwv_flow_api.g_varchar2_table(7) := '673A387078203470783B6D617267696E3A30203470782034707820303B636F6C6F723A233646364636463B626F726465722D7261646975733A3370787D2E612D49636F6E4C6973742D6974656D3A686F7665727B636F6C6F723A233434343B6261636B67';
wwv_flow_api.g_varchar2_table(8) := '726F756E642D636F6C6F723A234641464146413B626F782D736861646F773A302030203020317078207267626128302C302C302C2E303529696E7365747D2E612D49636F6E4C6973742D6974656D3A6163746976657B636F6C6F723A233434343B626163';
wwv_flow_api.g_varchar2_table(9) := '6B67726F756E642D636F6C6F723A234534453445343B626F782D736861646F773A302030203020317078207267626128302C302C302C2E303529696E7365747D2E612D49636F6E4C6973742D6974656D3A666F6375737B6F75746C696E653A303B626F78';
wwv_flow_api.g_varchar2_table(10) := '2D736861646F773A302030203020317078202333393962656120696E7365747D2E612D49636F6E4C6973742D6974656D2E69732D73656C65637465647B6261636B67726F756E642D636F6C6F723A234632463246323B626F782D736861646F773A302030';
wwv_flow_api.g_varchar2_table(11) := '203020317078202333393962656120696E7365747D2E612D49636F6E4C6973742D6974656D2E69732D73656C65637465642E69732D666F63757365647B636F6C6F723A233434343B626F782D736861646F773A3020302030203170782023333939626561';
wwv_flow_api.g_varchar2_table(12) := '20696E7365742C30203020302031707820233339396265612C302030203270782032707820726762612835372C3135352C3233342C2E35293B6F75746C696E653A307D2E612D49636F6E4C6973742D6974656D202E612D49636F6E4C6973742D69636F6E';
wwv_flow_api.g_varchar2_table(13) := '7B6D617267696E3A387078206175746F3B646973706C61793A626C6F636B3B6C696E652D6865696768743A313B746578742D616C69676E3A63656E7465727D2E612D49636F6E4C6973742D6974656D202E612D49636F6E4C6973742D69636F6E3A626566';
wwv_flow_api.g_varchar2_table(14) := '6F72657B766572746963616C2D616C69676E3A746F707D2E612D49636F6E4C6973742D6C6162656C7B746578742D6F766572666C6F773A656C6C69707369733B746578742D616C69676E3A63656E7465723B77686974652D73706163653A6E6F726D616C';
wwv_flow_api.g_varchar2_table(15) := '3B666F6E742D73697A653A313170783B6C696E652D6865696768743A313470783B6865696768743A323870783B6D617267696E2D746F703A3870787D2E612D49636F6E4C6973742D64657461696C7B746578742D6F766572666C6F773A656C6C69707369';
wwv_flow_api.g_varchar2_table(16) := '733B746578742D616C69676E3A63656E7465723B77686974652D73706163653A6E6F777261703B666F6E742D73697A653A3970783B6C696E652D6865696768743A313270783B6865696768743A313270783B6D617267696E2D746F703A3470787D2E612D';
wwv_flow_api.g_varchar2_table(17) := '49636F6E4C6973742E742D68617344657461696C73202E612D49636F6E4C6973742D6C6162656C7B77686974652D73706163653A6E6F777261703B6865696768743A313470787D2E612D49636F6E4C6973742E742D68617344657461696C73202E612D49';
wwv_flow_api.g_varchar2_table(18) := '636F6E4C6973742D69636F6E7B6D617267696E2D746F703A307D2E612D49636F6E4C6973742E742D6D656469756D202E612D49636F6E4C6973742D69636F6E7B77696474683A333270783B6865696768743A333270787D2E612D49636F6E4C6973742E74';
wwv_flow_api.g_varchar2_table(19) := '2D6D656469756D202E612D49636F6E4C6973742D69636F6E3A6265666F72657B666F6E742D73697A653A333270787D2E612D49636F6E4C6973742E742D6D656469756D202E612D49636F6E4C6973742D6974656D7B77696474683A31323070783B686569';
wwv_flow_api.g_varchar2_table(20) := '6768743A393070787D2E612D49636F6E4C6973742E742D6C61726765202E612D49636F6E4C6973742D69636F6E7B77696474683A363470783B6865696768743A363470787D2E612D49636F6E4C6973742E742D6C61726765202E612D49636F6E4C697374';
wwv_flow_api.g_varchar2_table(21) := '2D69636F6E3A6265666F72657B666F6E742D73697A653A363470787D2E612D49636F6E4C6973742E742D6C61726765202E612D49636F6E4C6973742D6974656D7B77696474683A31343070783B6865696768743A31323070787D2E612D49636F6E4C6973';
wwv_flow_api.g_varchar2_table(22) := '742E742D736D616C202E612D49636F6E4C6973742D69636F6E7B77696474683A313670783B6865696768743A313670787D2E612D49636F6E4C6973742E742D736D616C6C202E612D49636F6E4C6973742D69636F6E3A6265666F72657B666F6E742D7369';
wwv_flow_api.g_varchar2_table(23) := '7A653A313670787D2E612D49636F6E4C6973742E742D736D616C6C202E612D49636F6E4C6973742D6974656D7B77696474683A31303070783B6865696768743A383070787D';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(2707795978274508631)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_file_name=>'iconSelectList.min.css'
,p_mime_type=>'text/css'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2166756E6374696F6E28242C756E646566696E6564297B2275736520737472696374223B77696E646F772E636F6D5F6F7261636C655F617065785F69636F6E5F73656C6563745F6C6973743D66756E6374696F6E286974656D49642C6F7074696F6E7329';
wwv_flow_api.g_varchar2_table(2) := '7B66756E6374696F6E20636C6561724C69737428297B6C697374242E656D70747928292C6C697374496E707574242E76616C282222297D66756E6374696F6E207265667265736828297B617065782E7769646765742E7574696C2E636173636164696E67';
wwv_flow_api.g_varchar2_table(3) := '4C6F76286C697374242C6F7074696F6E732E616A61784964656E7469666965722C7B706167654974656D733A24286F7074696F6E732E706167654974656D73546F5375626D69742C617065782E6750616765436F6E7465787424297D2C7B6F7074696D69';
wwv_flow_api.g_varchar2_table(4) := '7A65526566726573683A6F7074696F6E732E6F7074696D697A65526566726573682C646570656E64696E674F6E3A24286F7074696F6E732E646570656E64696E674F6E53656C6563746F722C617065782E6750616765436F6E7465787424292C64617461';
wwv_flow_api.g_varchar2_table(5) := '547970653A2268746D6C222C6C6F6164696E67496E64696361746F723A6C697374242E706172656E7428292C6C6F6164696E67496E64696361746F72506F736974696F6E3A226166746572222C737563636573733A66756E6374696F6E2864617461297B';
wwv_flow_api.g_varchar2_table(6) := '6C697374242E68746D6C2864617461292C6C697374242E69636F6E4C69737428227265667265736822292C6F7074696F6E732E6D756C7469706C657C7C286C697374242E69636F6E4C697374282273657453656C656374696F6E222C6C697374242E6368';
wwv_flow_api.g_varchar2_table(7) := '696C6472656E28292E66697273742829292C617065782E6974656D286974656D4964292E73657456616C7565286C697374242E69636F6E4C697374282267657453656C656374696F6E56616C756573222929297D2C636C6561723A636C6561724C697374';
wwv_flow_api.g_varchar2_table(8) := '7D297D766172206C697374496E707574243D24282223222B6974656D49642B225F56414C5545222C617065782E6750616765436F6E7465787424292C6C697374243D24282223222B6974656D49642C617065782E6750616765436F6E7465787424293B6C';
wwv_flow_api.g_varchar2_table(9) := '697374242E69636F6E4C697374287B6E617669676174696F6E3A224E4F4E4522213D3D6F7074696F6E732E73656C656374696F6E416374696F6E2C6D756C7469706C653A6F7074696F6E732E6D756C7469706C652C6C6162656C3A222E612D49636F6E4C';
wwv_flow_api.g_varchar2_table(10) := '6973742D6C6162656C222C636F6E746578744D656E753A6F7074696F6E732E636F6E746578744D656E753F6F7074696F6E732E636F6E746578744D656E753A6E756C6C2C636F6E746578744D656E7549643A6F7074696F6E732E636F6E746578744D656E';
wwv_flow_api.g_varchar2_table(11) := '753F6974656D49642B225F6D656E75223A6E756C6C2C61637469766174653A66756E6374696F6E286576656E742C7569297B7661722076616C7565733B225355424D4954223D3D3D6F7074696F6E732E61637469766174696F6E416374696F6E7C7C2253';
wwv_flow_api.g_varchar2_table(12) := '55424D4954223D3D3D6F7074696F6E732E73656C656374696F6E416374696F6E3F2876616C7565733D75692E76616C7565732E6A6F696E28223A22292C6C697374496E707574242E76616C2876616C756573292C617065782E706167652E7375626D6974';
wwv_flow_api.g_varchar2_table(13) := '287B726571756573743A6974656D49647D29293A282252454449524543545F55524C223D3D3D6F7074696F6E732E61637469766174696F6E416374696F6E7C7C2252454449524543545F55524C223D3D3D6F7074696F6E732E73656C656374696F6E4163';
wwv_flow_api.g_varchar2_table(14) := '74696F6E292626617065782E6E617669676174696F6E2E72656469726563742875692E76616C7565735B305D292C6576656E742E70726576656E7444656661756C7428297D2C73656C656374696F6E4368616E67653A66756E6374696F6E286576656E74';
wwv_flow_api.g_varchar2_table(15) := '297B7661722076616C7565733D242874686973292E69636F6E4C697374282267657453656C656374696F6E56616C75657322293B76616C7565733D76616C7565732E6A6F696E28223A22292C6C697374496E707574242E76616C2876616C756573292E74';
wwv_flow_api.g_varchar2_table(16) := '72696767657228226368616E676522297D7D292C6F7074696F6E732E68617344657461696C7326266C697374242E616464436C6173732822742D68617344657461696C7322292C242877696E646F77292E6F6E28226170657877696E646F77726573697A';
wwv_flow_api.g_varchar2_table(17) := '6564222C66756E6374696F6E28297B6C697374242E69636F6E4C69737428227265667265736822297D292C6F7074696F6E732E686173546F6F6C7469707326266C697374242E746F6F6C746970287B6974656D733A226C69222C73686F773A617065782E';
wwv_flow_api.g_varchar2_table(18) := '746F6F6C7469704D616E616765722E64656661756C7453686F774F7074696F6E28292C706F736974696F6E3A7B6D793A226C6566742D323020746F702D3230222C61743A22726967687420626F74746F6D222C636F6C6C6973696F6E3A22666C69706669';
wwv_flow_api.g_varchar2_table(19) := '74227D2C636F6E74656E743A66756E6374696F6E28297B72657475726E20242874686973292E66696E6428222E612D49636F6E4C6973742D746F6F6C74697022292E68746D6C28297D7D292C617065782E7769646765742E696E6974506167654974656D';
wwv_flow_api.g_varchar2_table(20) := '286974656D49642C7B67657456616C75653A66756E6374696F6E28297B72657475726E206C697374496E707574242E76616C28297D2C73657456616C75653A66756E6374696F6E2876616C7565297B766172206974656D733D5B5D3B6C697374496E7075';
wwv_flow_api.g_varchar2_table(21) := '74242E76616C2876616C7565292C76616C75653D223A222B76616C75652B223A222C6C697374242E66696E6428222E612D49636F6E4C6973742D6974656D22292E656163682866756E6374696F6E28297B76616C75652E696E6465784F6628223A222B24';
wwv_flow_api.g_varchar2_table(22) := '2874686973292E617474722822646174612D76616C756522292B223A22293E3D3026266974656D732E707573682874686973297D292C6C697374242E69636F6E4C697374282273657453656C656374696F6E222C24286974656D7329297D2C6E756C6C56';
wwv_flow_api.g_varchar2_table(23) := '616C75653A22222C656E61626C653A66756E6374696F6E28297B6C697374242E69636F6E4C6973742822656E61626C6522297D2C64697361626C653A66756E6374696F6E28297B6C697374242E69636F6E4C697374282264697361626C6522297D2C7365';
wwv_flow_api.g_varchar2_table(24) := '74466F637573546F3A66756E6374696F6E28297B72657475726E206C697374242E69636F6E4C6973742822666F63757322292C7B666F6375733A66756E6374696F6E28297B7D7D7D7D292C6F7074696F6E732E6D756C7469706C657C7C30213D3D6C6973';
wwv_flow_api.g_varchar2_table(25) := '74242E69636F6E4C697374282267657453656C656374696F6E56616C75657322292E6C656E6774687C7C286C697374242E69636F6E4C697374282273657453656C656374696F6E222C6C697374242E6368696C6472656E28292E66697273742829292C61';
wwv_flow_api.g_varchar2_table(26) := '7065782E6974656D286974656D4964292E73657456616C7565286C697374242E69636F6E4C697374282267657453656C656374696F6E56616C756573222929292C6F7074696F6E732E646570656E64696E674F6E53656C6563746F72262624286F707469';
wwv_flow_api.g_varchar2_table(27) := '6F6E732E646570656E64696E674F6E53656C6563746F722C617065782E6750616765436F6E7465787424292E6F6E2822617065786265666F726572656672657368222C636C6561724C697374292E6368616E67652872656672657368292C6C697374242E';
wwv_flow_api.g_varchar2_table(28) := '6F6E28226170657872656672657368222C72656672657368297D7D28617065782E6A5175657279293B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(2707796329585509586)
,p_plugin_id=>wwv_flow_api.id(2704185839264876337)
,p_file_name=>'iconSelectList.min.js'
,p_mime_type=>'application/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.import_end(p_auto_install_sup_obj => nvl(wwv_flow_application_install.get_auto_install_sup_obj, false), p_is_component_import => true);
commit;
end;
/
set verify on feedback on define on
prompt  ...done
